@@ -1,14 +1,17 @@
 # frozen_string_literal: true
 
-require 'faraday'
 require 'simplecov'
 
 SimpleCov.start do
   add_filter %w[spec/ .github/]
 end
 
+require 'faraday'
+
 require_relative '../lib/faraday/gzip'
 
+Dir[File.join(__dir__, 'support/**/*.rb')].each { |f| require f }
+
 RSpec.configure do |config|
   # Enable flags like --only-failures and --next-failure
   config.example_status_persistence_file_path = '.rspec_status'
@@ -22,4 +25,6 @@ RSpec.configure do |config|
 
   config.order = :random
   Kernel.srand config.seed
+
+  config.include FaradayGzipSpecHelpers
 end
